@@ -12,8 +12,9 @@ use lib 'lib';
 use Mobile::Wurfl;
 
 my $wurfl = Mobile::Wurfl->new( verbose => 1 );
-$wurfl->create_tables();
-$wurfl->update();
+$wurfl->rebuild_tables();
+# $wurfl->create_tables();
+# $wurfl->update();
 
 #------------------------------------------------------------------------------
 #
